@@ -20,25 +20,30 @@ class GitHubFeedParser:
 
         self.feed = feedparser.parse(self.endpoint)
 
+    def _respond(self):
+        ''' Always return false for bozos. '''
+
         if self.feed['bozo'] == 1:
             return False
+        else:
+            return self.parsed_feed
 
     def get_html(self):
 
-        parsed_feed = u''
+        self.parsed_feed = u''
 
         for each in self.feed.entries:
-            parsed_feed = parsed_feed + u'<a href="%s" target="_blank"><img src="%s"> %s</a> <a href="%s" target="_blank">%s</a><br>' % \
+            self.parsed_feed = self.parsed_feed + u'<a href="%s" target="_blank"><img src="%s"> %s</a> <a href="%s" target="_blank">%s</a><br>' % \
                 (each['href'], each['media_thumbnail'][0]['url'], each['author'], each['link'], each['title'])
 
-        return parsed_feed
+        return self._respond()
 
     def get_obj(self):
 
-        parsed_feed = []
+        self.parsed_feed = []
 
         for each in self.feed.entries:
-            parsed_feed.append({
+            self.parsed_feed.append({
                 'user_url': each['href'],
                 'user_avatar_url': each['media_thumbnail'][0]['url'],
                 'user_name': each['author'],
@@ -47,8 +52,9 @@ class GitHubFeedParser:
                 'timestamp': each['updated']
             })
 
-        return parsed_feed
+        return self._respond()
 
     def get_json(self):
-        return json.dumps(self.get_obj())
 
+        self.parsed_feed = json.dumps(self.get_obj())
+        return self._respond()
